@@ -6,8 +6,8 @@
 
 Examples
 --------
->>> from context_verbose.memory import reset_lifo
->>> reset_lifo()
+>>> from context_verbose.memory import _reset_memory
+>>> _reset_memory()
 >>> from context_verbose.printer import Printer
 >>>
 >>> with Printer('Main section') as ctp:
@@ -34,7 +34,7 @@ Main section
 
 from context_verbose.printer import Printer
 
-__version__ = '2.0.3'
+__version__ = '2.1.0'
 __author__ = 'Robin RICHARD (robinechuca) <raisin@ecomail.fr>'
 __license__ = 'GNU Affero General Public License v3 or later (AGPLv3+)'
 __all__ = ['Printer', 'printer']
