@@ -30,8 +30,8 @@ def decorate(func):
 
     Examples
     --------
-    >>> from context_verbose.memory import reset_lifo
-    >>> reset_lifo()
+    >>> from context_verbose.memory import _reset_memory
+    >>> _reset_memory()
     >>> from context_verbose.decorator import decorate
     >>>
     >>> @decorate
