@@ -13,13 +13,10 @@ import logging
 import math
 import multiprocessing
 import sys
-import tempfile
 import threading
 import time
 
 
-DIR = tempfile.mkdtemp()
-
 
 def get_id():
     """
@@ -55,14 +52,16 @@ def get_id():
     proc_name = multiprocessing.current_process().name
     thread_name = threading.current_thread().name
     try:
-        father_proc = multiprocessing.parent_process()
+        father_proc = multiprocessing.parent_process() if proc_name != 'MainProcess' else None
     except AttributeError: # if python version < 3.8
         message = (
             'please use a version of python >= 3.8 '
             'if you do multiprocessing, your current version is '
             f'{sys.version_info.major}.{sys.version_info.minor}.{sys.version_info.micro}'
         )
-        logging.warning(message)
+        if '_version_warn' not in globals():
+            globals()['_version_warn'] = None
+            logging.warning(message)
         father_proc = None
     else:
         father_proc = father_proc.name if father_proc is not None else None
@@ -84,8 +83,8 @@ def get_lifo():
 
     Examples
     --------
-    >>> from context_verbose.memory import get_lifo, reset_lifo
-    >>> reset_lifo()
+    >>> from context_verbose.memory import get_lifo, _reset_memory
+    >>> _reset_memory()
     >>>
     >>> # case in main process and main thread
     >>> print(get_lifo())
@@ -145,13 +144,13 @@ def get_lifo():
     return get_lifo()
 
 
-def reset_lifo():
+def _reset_memory():
     """
     ** Removes all traces of memory. **
     """
-    for name in [n for n in globals() if n.startswith('_global_fifo_')]:
-        del globals()[name]
-
+    for name in list(globals()).copy():
+        if name.startswith('_global_fifo_'):
+            del globals()[name]
 
 class LIFO:
     """
@@ -189,6 +188,7 @@ class LIFO:
         --------
         >>> from context_verbose.memory import LIFO
         >>> queue = LIFO(color='green', toto=True)
+        >>>
         """
         self.lifo.insert(0, {**self.lifo[0], **self.future_context, **new_context})
         self.lifo[0]['time'] = time.time()
