@@ -38,7 +38,7 @@ class Printer:
 
         Examples
         --------
-        >>> from context_verbose import Printer
+        >>> from context_verbose.printer import Printer
         >>> c1 = Printer()
         >>> c2 = Printer()
         >>> c1 is c2
@@ -63,13 +63,13 @@ class Printer:
 
         Examples
         --------
-        >>> from context_verbose.memory import reset_lifo
-        >>> reset_lifo()
+        >>> from context_verbose.memory import _reset_memory
+        >>> _reset_memory()
         >>> from context_verbose.printer import Printer
         >>> ctp = Printer()
         >>> ctp.enter_section() # doctest: +SKIP
         Section __run l1336 in /usr/lib/python3.8/doctest.py
-        >>> reset_lifo()
+        >>> _reset_memory()
         >>> ctp.enter_section('Section')
         Section
         >>>
@@ -127,8 +127,8 @@ class Printer:
 
         Examples
         --------
-        >>> from context_verbose.memory import reset_lifo
-        >>> reset_lifo()
+        >>> from context_verbose.memory import _reset_memory
+        >>> _reset_memory()
         >>> from context_verbose.printer import Printer
         >>> ctp = Printer()
         >>> ctp.print('a simple message')
@@ -176,8 +176,8 @@ class Printer:
 
         Examples
         --------
-        >>> from context_verbose.memory import reset_lifo
-        >>> reset_lifo()
+        >>> from context_verbose.memory import _reset_memory
+        >>> _reset_memory()
         >>> from context_verbose.printer import Printer
         >>> with Printer('Section') as ctp:
         ...     t = ctp.elapsed_time()
@@ -212,8 +212,8 @@ class Printer:
 
         Examples
         --------
-        >>> from context_verbose.memory import reset_lifo
-        >>> reset_lifo()
+        >>> from context_verbose.memory import _reset_memory
+        >>> _reset_memory()
         >>> from context_verbose.printer import Printer
         >>> ctp = Printer()
         >>> ctp.set_max_depth(2)
@@ -250,8 +250,8 @@ class Printer:
 
         Examples
         --------
-        >>> from context_verbose.memory import reset_lifo
-        >>> reset_lifo()
+        >>> from context_verbose.memory import _reset_memory
+        >>> _reset_memory()
         >>> from context_verbose.printer import Printer
         >>> ctp = Printer()
         >>> ctp.print('abcdefghijklmnopqrstuv')
